audio_gain {#yarp_3_5}
-----------

Important Changes
-----------------

## Libraries

### `dev`

* fixed parsing of parameters `hw_gain` and `sw_gain` in the two classes `AudioPlayerDeviceBase` and `AudioRecorderDeviceBase`